document.addEventListener('DOMContentLoaded', () => {
  const videoForm = document.getElementById('video-form');
  const videoList = document.getElementById('video-list');
  const loginBtn = document.getElementById('login-btn');
  
  let videos = JSON.parse(localStorage.getItem('videos')) || [];
  
  function saveVideos() {
    localStorage.setItem('videos', JSON.stringify(videos));
  }
  
  function addVideo(title, url) {
    const video = {
      id: Date.now(),
      title,
      url,
      completed: false
    };
    videos.push(video);
    saveVideos();
    renderVideos();
  }
  
  function toggleVideoComplete(id) {
    videos = videos.map(video => {
      if (video.id === id) {
        return { ...video, completed: !video.completed };
      }
      return video;
    });
    saveVideos();
    renderVideos();
  }
  
  function renderVideos() {
    videoList.innerHTML = '';
    videos.forEach(video => {
      const videoCard = document.createElement('div');
      videoCard.className = `video-card ${video.completed ? 'completed' : ''}`;
      videoCard.innerHTML = `
        <h3>${video.title}</h3>
        <a href="${video.url}" target="_blank" rel="noopener noreferrer" class="gothic-btn">Watch</a>
        <button onclick="toggleVideoComplete(${video.id})" class="gothic-btn">
          ${video.completed ? 'Mark Incomplete' : 'Mark Complete'}
        </button>
      `;
      videoList.appendChild(videoCard);
    });
  }
  
  videoForm.addEventListener('submit', (e) => {
    e.preventDefault();
    const titleInput = document.getElementById('video-title');
    const urlInput = document.getElementById('video-url');
    
    if (titleInput.value && urlInput.value) {
      addVideo(titleInput.value, urlInput.value);
      titleInput.value = '';
      urlInput.value = '';
    }
  });
  
  loginBtn.addEventListener('click', () => {
    // Google OAuth implementation would go here
    alert('Google Sign-in functionality would be implemented here');
  });
  
  // Initial render
  renderVideos();
});
